@@ -1931,10 +1931,107 @@ STATUS_DICT = {
         },
     },
     "HE": {
+        'DeviceType': {
+            "controlable": False,
+            "is_numeric": False,
+            "legacy_name": "DeviceType",
+            "id2str": {
+                1: "AC",
+                2: "DH",
+                3: "HE",
+                4: "PM25_PANEL",
+            }
+        },
+        'Switch': {
+            "controlable": True,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "off",
+                1: "on",
+            }
+        },
+        'Mode': {
+            "controlable": True,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "air_condition",
+                1: "dehumidification",
+                2: "air_supply",
+                3: "auto",
+                4: "heater",
+            }
+        },
+        'FanSpeed': {
+            "controlable": True,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "auto",
+                1: "silent",
+                2: "low",
+                3: "moderate",
+                4: "high",
+            }
+        },
+        'IndoorTemperature': {
+            "controlable": False,
+            "is_numeric": True,
+            "legacy_name": None,
+        },
+        'TaiseiaError': {
+            "controlable": False,
+            "is_numeric": True,
+            "legacy_name": None,
+        },
+        'CleanFilterNotification': {
+            "controlable": False,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "disabled",
+                1: "enabled",
+            }
+        },
+        'BreathMode': {
+            "controlable": True,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "auto",
+                1: "energy_recovery",
+                2: "normal"
+            }
+        },
+        'FrontFilterNotification': {
+            "controlable": False,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "disabled",
+                1: "enabled",
+            }
+        },
+        'Pm25FilterNotification': {
+            "controlable": False,
+            "is_numeric": False,
+            "legacy_name": None,
+            "id2str": {
+                0: "disabled",
+                1: "enabled",
+            }
+        },
+        'Error': {
+            "controlable": False,
+            "is_numeric": True,
+            "legacy_name": None,
+        },
+    },
+    "PM25_PANEL": {
 
     }
 }
-PREPARED_STATUS_DICT = None
 
 class JciHitachiAWSStatus:
     device_type_mapping = {
@@ -2000,8 +2097,11 @@ class JciHitachiAWSStatus:
         status = {}
         device_type = self._status["DeviceType"]
         for status_name, status_value in self._status.items():
-            if status_name in STATUS_DICT[device_type] and \
-                STATUS_DICT[device_type][status_name]["legacy_name"] is not None:
+            if status_name in STATUS_DICT[device_type]:
+                if STATUS_DICT[device_type][status_name]["legacy_name"] is None:
+                    # no legacy name
+                    status.update({status_name: status_value})
+                else:
                     status.update({STATUS_DICT[device_type][status_name]["legacy_name"]: status_value})
         return JciHitachiAWSStatus(status, legacy=True)
 
